*******************************************************
**		DATA PREP defines and prepares	     **
**covariates and outcomes for the estimation sequence**
******************************************************* 
/*
Notes:
1) Covariate and outcome lists defined in setup.do
2) local/nonlocal/outside variables are only valid in winlose sample.
3) "2" suffix on price variables implies imputations have been thrown out
4) Count variables sometimes taking on zero values are converted to Davis and Haltiwanger type changes later in the code
5) SMAs are in some cases computed at county level and in other cases at zone level. Don't compute SMAs of unnecessary stuff or dataprep will be slow!
6) Placebo SMA variables are also constructed in this routine. Be sure to uncomment relevant sections of code when rebuilding placebo!
7) Samehouse and newhouse variables have two sets of naming conventions -- basic price variables have _sh/_nsh suffix while adjusted values and demographics have samehouse_/newhouse_ prefix.
*/

** 1. Setup and open main file ------------------------------------------------------------------------------------------------------
   cap run "/rdcprojects/mc1/mc00535/programs_organize/3.estimation/1.setup.do"
   if _rc!=0 di in red "run 1.setup.do"
   use "$censusdir/workfile_90_fullcounties.dta", clear
   
   **merge on new city/county data
   gen tractid=tractid90
   gen decade=year
   merge 1:1 tractid decade using /rdcprojects/mc1/mc00535/data/data_crime_educ.dta
   drop if _merge==2
   drop _merge

   **update city level Vars to CG level**
   drop treatment*_city
   foreach var of varlist *_city{
	cap drop mean sd
	egen mean=mean(`var'), by(cg year)
	egen sd=sd(`var'), by(cg year)
	di "Imputing missing values of `var'"
	assert round(sd,0.01)==0|sd==.
	replace `var'=mean if `var'==.
   } 
   drop mean sd
   foreach var of varlist crime_violent crime_property crime_total number_schools students pupil_teacher_ratio diploma_recipients{
	cap drop mean
	egen mean=mean(`var'), by(cg year)
	replace `var'=mean
   } 

** 2. Fix panel structure so that it's strongly balanced ----------------------------------------------------------------------------
   drop tractid
   fillin tractid90 year
   drop id yr
   egen id = group(tractid90)
   egen yr = group(year)
   replace yr = yr+1
   drop _fillin
   tsset id yr
   gen state = substr(tractid90,1,2)

** 3. Generate basic variables (logs, squares, etc) ---------------------------------------------------------------------------------
   drop *_1997
   drop d_*
   gen lnarea=ln(landa)
   gen popdens=pop/landa
   gen lnpopdens=ln(popdens)
   gen qd=lnwkwage2_local-.25*lnrent2
   gen qd_hat=lnwkwage2_local_hat-.25*lnrent2_hat
   gen nonlocal_shr=jobs_nonlocal/jobs

   gen region = 1 if inlist(st,"09","23","25","33","44","50","34","36","42") //NE
   replace region =2 if inlist(st,"18","17","26","39","55","19")|inlist(st,"20","27","29","31","38","46") //MW
   replace region =3 if inlist(st,"10","11","12","13","24","37","45","51","54")|inlist(st,"01","21","28","47","05","22","40","48") //South
   replace region = 4 if inlist(st,"04","08","16","35","30","49")|inlist(st,"32","56","02","06","15","41","53") //West

   gen south=region==3
   gen west=region==4
   gen mw=region==2

   forvalues ii=1/2 {
   if `ii'==1 local wgt ""
   if `ii'==2 local wgt "_nwt"
   di "wgt is `wgt'"
   gen lnpop`wgt'  =ln(pop`wgt')
   gen lnhh`wgt'   =ln(hh`wgt')
   gen logearn`wgt'=ln(totearn`wgt')
   gen lnjobs_local`wgt' = ln(jobs_local`wgt')
   gen lnjobs_nonlocal`wgt' = ln(jobs_nonlocal`wgt')
   gen lnjobs_outside`wgt' = ln(jobs_outside`wgt')
   gen lntotearn`wgt' = ln(totearn`wgt')-ln(hh`wgt')
   gen lnrent_value`wgt' = lnrent2`wgt'-lnvalue2`wgt'
   }
   gen lnrent_value_hat = lnrent2_hat-lnvalue2_hat
   gen lndiploma_recipients=ln(diploma_recipients)

   *samehouse/newhouse variables
   foreach var in employed unemployed poverty lnwage2 lnvalue2 lnrent2{
	ren `var'_sh sh_`var'
	ren samehouse_`var'_hat sh_`var'_hat	
	ren samehouse_`var'_comp sh_`var'_comp
	}
   foreach var in lnvalue2 lnrent2{
	ren `var'_nsh nsh_`var'
	ren newhouse_`var'_hat nsh_`var'_hat
	ren newhouse_`var'_comp nsh_`var'_comp
	}

   forvalues ii=1/2 {
   if `ii'==1 local wgt ""
   if `ii'==2 local wgt "_nwt"
   di "wgt is `wgt'"
   cap gen male_jobs_por`wgt'  =male_jobs_local`wgt'+male_jobs_outside`wgt'
   cap gen female_jobs_por`wgt'=female_jobs_local`wgt'+female_jobs_outside`wgt'
   gen lnmale_jobs`wgt' = ln(male_jobs`wgt')
   gen lnmale_jobs_local`wgt' = ln(male_jobs_local`wgt')
   gen lnmale_jobs_nonlocal`wgt' = ln(male_jobs_nonlocal`wgt')
   gen lnmale_jobs_outside`wgt' = ln(male_jobs_outside`wgt')
   gen lnfemale_jobs`wgt' = ln(female_jobs`wgt')
   gen lnfemale_jobs_local`wgt' = ln(female_jobs_local`wgt')
   gen lnfemale_jobs_nonlocal`wgt' = ln(female_jobs_nonlocal`wgt')
   gen lnfemale_jobs_outside`wgt' = ln(female_jobs_outside`wgt')
   
   recode male_lnwage* female_lnwage* (0=.) if assigned_tract==.

}
   cap gen dropout_jobs_por  =dropout_jobs_local+dropout_jobs_outside
   cap gen graduate_jobs_por=graduate_jobs_local+graduate_jobs_outside
   gen lndropout_jobs = ln(male_jobs)
   gen lndropout_jobs_local = ln(male_jobs_local)
   gen lndropout_jobs_nonlocal = ln(male_jobs_nonlocal)
   gen lndropout_jobs_outside = ln(male_jobs_outside)
   gen lngraduate_jobs = ln(graduate_jobs)
   gen lngraduate_jobs_local = ln(graduate_jobs_local)
   gen lngraduate_jobs_nonlocal = ln(graduate_jobs_nonlocal)
   gen lngraduate_jobs_outside = ln(graduate_jobs_outside)
   recode dropout_lnwage* graduate_lnwage* (0=.) if assigned_tract==.
   gen lnemplbd_2000 = ln(employment_2000) 

   ** Fix names
   foreach var in lnavrgwage lnavrgwage2 lnest lnest_less5 lnest_more5 lnest_less5now lnest_more5now lnest_92univ lnemplbd lnemp_less5 lnemp_more5 /*
        */ lnemp_less5now lnemp_more5now lnemp_92univ lnavrgwage_less5 lnavrgwage_more5 lnavrgwage_less5now lnavrgwage_more5now lnavrgwage_92univ /*
	*/ lnavrgwage2_less5 lnavrgwage2_more5 lnavrgwage2_less5now lnavrgwage2_more5now lnavrgwage2_92univ /*
	*/ lnwagebill_less5 lnwagebill_more5 lnwagebill_less5now lnwagebill_more5now lnwagebill_92univ wagebill wagebill_less5now wagebill_more5now /*
	*/ wagebill_less5 wagebill_more5 employment employment_more5 employment_less5 employment_more5now employment_less5now{
         ren `var'_2000 `var'
   }

   **Average LBD wage
   gen avrgwage=wagebill/employment
   gen avrgwage_less5now=wagebill_less5now/employment_less5now
   gen avrgwage_more5now=wagebill_more5now/employment_more5now
   gen avrgwage_less5=wagebill_less5/employment_less5
   gen avrgwage_more5=wagebill_more5/employment_more5
   gen avrgwage_92univ=wagebill_92univ/employment_92univ
   **winsorize
   forvalues i=2/4{
	centile avrgwage if yr==`i', c(1 99)
	local ll=r(c_1)
	local ul=r(c_2)
	foreach var of varlist avrgwage*{
		replace `var'=`ll' if `var'<`ll'&yr==`i'
		replace `var'=`ul' if `var'>`ul'&`var'!=.&yr==`i'
		sum `var' if yr==`i'
	}
   }
   *take logs
   replace lnavrgwage=ln(avrgwage)
   replace lnavrgwage_less5now=ln(avrgwage_less5now)
   replace lnavrgwage_more5now=ln(avrgwage_more5now)
   replace lnavrgwage_less5=ln(avrgwage_less5)
   replace lnavrgwage_more5=ln(avrgwage_more5)
   replace lnavrgwage_92univ=ln(avrgwage_92univ)

   *other variables
   gen crime_city=(crime_total_city)/population_city
   replace crime_city=(l.crime_city+f.crime_city)/2 if crime_city==0&yr==3 //fix Chicago
   gen lnpop_city = ln(population_city)
   gen aux25 = poverty>=0.25 & poverty<. if yr==3
   egen pov25 = mean(aux25), by(id)
   drop aux25
   gen aux35 = poverty>=0.35 & poverty<. if yr==3
   egen pov35 = mean(aux35), by(id)
   drop aux35
   gen occshare=hh_value/hh
   egen treatedcity = sum(assigned_tract), by(cg)
   replace treatedcity=1 if treatedcity>=1
   gen pov_unemp = poverty*unemployed
   gen pov_lnpop = poverty*lnpop
   gen pov_black = poverty*black
   gen pov_hisp = poverty*hisp
   gen pov_drop = poverty*dropout
   gen pov_college = poverty*college
   gen aux = pop>=2000 & pop<. if yr==3
   egen pop2000 = mean(aux), by(tractid90)
   drop aux
   gen black1   =black==1
   gen college0 =college==0
   gen hisp0    = hisp==0
   gen occshare0= occshare==0 if occshare!=.

   gen poplt500=pop<500
   gen hhlt200=hh<200
   ren employed_city epop_city //patch for regexr calls
   gen lnwage_city=ln(wage_city)
   egen vacant_city1=sum(vacant*hh), by(cg yr)
   egen vacant_city2=sum(hh), by(cg yr)
   gen vacant_city=vacant_city1/vacant_city2
   gen emplbd=exp(lnemplbd)
   egen emplbd_city=sum(emplbd), by(cg yr)
   gen lnemplbd_city=ln(emplbd_city)
   egen jobs_city=sum(jobs), by(cg yr)
   gen lnjobs_city=ln(jobs_city)
    foreach var in lnwage lnincw lnwkwage{	
     qui gen `var'3_local = `var'2_local
     qui gen `var'3_local_hat = `var'2_local_hat
    }
    
** 4. Check some basic assertions -----------------------------------------------------------------------------------------------------
  ** About jobs by gender
  cap noi assert jobs==jobs_local+jobs_nonlocal if assigned_tract<.
  cap noi assert male_jobs==male_jobs_local+male_jobs_nonlocal if assigned_tract<.
  cap noi assert female_jobs==female_jobs_local+female_jobs_nonlocal if assigned_tract<.
  cap noi assert dropout_jobs==dropout_jobs_local+dropout_jobs_nonlocal if assigned_tract<.
  cap noi assert graduate_jobs==graduate_jobs_local+graduate_jobs_nonlocal if assigned_tract<.
  cap noi assert jobs_nwt == jobs_nonlocal_nwt + jobs_local_nwt if assigned_tract<.

  ** About adjusted and composition effects: check that var = var_hat + var_comp
  foreach var of global outcomes{
    local check =  regexm("`var'","_comp")
    if `check'==1{
      local str = regexr("`var'","_comp","")
      cap assert `str'==`str'_hat+`str'_comp
      if _rc==0 di in yellow "Good. `str'==`str'_hat+`str'_comp"
      if _rc!=0{
                cap drop `str'_comp
                gen `str'_comp = `str'-`str'_hat
                }
     }
   }

** 5. Generate outcomes (d_ variables) -------------------------------------------------------------------------------------------------
   foreach var of global outcomes{
     gen d_`var' = d.`var'
   }

** 6. Generate covariates ---------------------------------------------------------------------------------------------------------

** Declare a local with unique variables to be generated  
   foreach X in $X_city $X_sma $X_1 $Z_1 $PCBO_1 $PCBO_2 $PCBO_3 $PCBO_4 $PCBO_5 $X_BAL $PLOT1{
     local str = regexr("`X'","_sma2","")
     local str = regexr("`str'","_sma","")
     local str = regexr("`str'","l2_","")
     local str = regexr("`str'","l_","")
     local str = regexr("`str'","d_","")
     global Xs "$Xs `str'"
    }
   global Xs: list uniq global Xs

   foreach var of global Xs{
     cap sum `var'
     if _rc!=0 di "`var' not found"
     if _rc==0{
        cap gen d_`var'   = d.`var'
        if _rc!=0 di in ye "d_`var' was already generated"
        gen l_`var'   = l.`var'
        gen l2_`var'  =l2.`var'
        gen l_d_`var' =l.d_`var'
     }
   }

   ***Davis and Haltiwanger Change Measures*****
   foreach var in jobs_local jobs_nonlocal jobs_outside male_jobs_local male_jobs_nonlocal male_jobs_outside female_jobs_local female_jobs_nonlocal female_jobs_outside male_jobs female_jobs dropout_jobs_local dropout_jobs_nonlocal dropout_jobs_outside graduate_jobs_local graduate_jobs_nonlocal graduate_jobs_outside dropout_jobs graduate_jobs{
	cap drop d_ln`var'
	cap drop l_d_ln`var'
	gen d_ln`var'=(`var'-l.`var')/(`var'+l.`var')*2
	gen l_d_ln`var'=l.d_ln`var'
   }

** 7. Generate SMAs ---------------------------------------------------------------------------------------------------------    
/*  (For potentially endogenous tract level vars, 
     compute kernel weighted means of nearby zone tracts
     This one takes SMAs over entire counties)
*/
   global SMAs ""
   foreach X in $X_sma $X_1 $Z_1{
     local str = regexr("`X'","_sma","")
     local str = regexr("`str'","l2_","")
     local str = regexr("`str'","l_","")
     local str = regexr("`str'","d_","")
     global SMAs "$SMAs `str'" 
   }
   global SMAs: list uniq global SMAs

    *don't include miniscule tracts in SMA
    foreach var of varlist pop hh{
      cap drop `var'_90
      gen `var'_90=`var' if year==1990
      cap drop big_`var'
      egen big_`var'=mean(`var'_90), by(tractid90)
    }

   local radius = 1
   * spatial mas including only zone tracts
   qui levelsof cg if yr==2, local(cg)
   foreach c of local cg{
     spatialma_loo_norm $SMAs if yr==2 & cg==`c' , latitude(latitude) longitude(longitude) distance(`radius')
   }
   qui levelsof cg if yr==3, local(cg)
   foreach c of local cg{
     spatialma_loo_norm $SMAs if yr==3 & cg==`c' , latitude(latitude) longitude(longitude) distance(`radius')
   }
   qui levelsof cg if yr==4, local(cg)
   foreach c of local cg{
     spatialma_loo_norm $SMAs if yr==4 & cg==`c' , latitude(latitude) longitude(longitude) distance(`radius')
   }

   ** Recover sample disclosed from Census in April 2011.
     // There are 7 observations that we used to have in the last disclosure and we don't have now becase of missing 
     // covariates. In order to preserve the set of tracts for disclosure, we impute the values of the covariates using
     // the zone average (The procedure imputes values for lnvalue2 lnavrgwage lnemplbd lnjobs college_pow lnwage2_pow_sma 
     drop if tractid90=="42101012400" //This tract was added by the SMA procedure
     cap drop mean
     foreach tract in "06073003300" "13121007100" "45019003600" "45019004000" "45019004400" "45019004500" "47093000800"{
     di in ye "Working on tractid90=`tract'"
      foreach var of global SMAs{
         ** Determine if the variable is actually missing
	 qui count if `var'_sma==. & tractid90=="`tract'"
         ** If it is, do the imputation
	 if r(N)>0{
	 di in gr "     ....Imputing variable `var'"
           qui egen mean  = mean(`var') if tractid90!="`tract'", by(progid_power yr)
           qui egen mean2 = mean(mean), by(progid_power yr)
           qui replace `var'_sma = mean2 if `var'_sma==. & tractid90=="`tract'"
           qui drop mean mean2
         }	 
       }
     }
   ** Compute lags and changes
   tsset id yr
   foreach var of global SMAs{
     gen l_`var'_sma = l.`var'_sma
     gen l2_`var'_sma = l2.`var'_sma
     gen d_`var'_sma = d.`var'_sma
     gen l_d_`var'_sma = l.d_`var'_sma 
   }

   tsset id yr
   foreach var of global SMA2s{
     gen l_`var'_sma2 = l.`var'_sma2
     gen l2_`var'_sma2 = l2.`var'_sma2
     gen d_`var'_sma2 = d.`var'_sma2
     gen l_d_`var'_sma2 = l.d_`var'_sma2 
   }

** 8. RCs_in_EZcities
   egen assigned_city=max(assigned_tract), by(cg)
   gen RCs_in_EZcities=1 if program2001==2&assigned_city==1

** 9. Add county level data
   cap drop _merge
   merge m:1 county90 using "/rdcprojects/mc1/mc00535/data/hpi4merge.dta"
   tab city if _merge==1
   tab county90 if _merge==1
   drop if _merge==2
   drop _merge
   gen lnhpi1992=ln(hpi1992)
   gen lnhpi1991=ln(hpi1991)
   cap drop aux*
   cap drop _merge
saveold "$censusdir/workfile_90_fullcounties_prepped.dta", replace
